/* Copyright (C) 2018 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Florian Uhlig [committer] */

#include "Rtypes.h"

class TGeoMatrix;
class TGeoVolume;
class FairModule;
class TString;

namespace Cbm
{
  namespace GeometryUtils
  {
    void UniqueId();
    void PrintMedia();
    void PrintMaterials();
    void ReAssignMediaId();
    void RemoveDuplicateMaterials();
    void RemoveDuplicateMedia();

    void ImportRootGeometry(TString& filename, FairModule* mod, TGeoMatrix* mat = nullptr);

    bool IsNewGeometryFile(TString& filename);
    bool IsNewGeometryFile(TString& filename, TString& volumeName, TGeoMatrix** matrix);

    void AssignMediumAtImport(TGeoVolume* v);
    void ExpandNodes(TGeoVolume* volume, FairModule* mod);

    /// @brief  Convert the local X/Y covariance matrix to global coordinates
    /// @param m      the transformation matrix
    /// @param covXX covariance X,X
    /// @param covXY covariance X,Y
    /// @param covYY covariance Y,Y
    void LocalToMasterCovarianceMatrix(const TGeoMatrix& m, Double_t& covXX, Double_t& covXY, Double_t& covYY);

  }  // namespace GeometryUtils
}  // namespace Cbm
