/* Copyright (C) 2010-2020 Frankfurt Institute for Advanced Studies, Goethe-Universität Frankfurt, Frankfurt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Valentina Akishina, Igor Kulakov [committer], Maksym Zyzak */

#ifndef _L1HitPoint_h_
#define _L1HitPoint_h_

#include "CaConstants.h"
#include "L1Hit.h"

/// contain strips positions and coordinates of the hit

struct L1HitPoint {

  L1HitPoint() = default;

  L1HitPoint(const L1Hit& hit) { Set(hit); };

  void Set(const L1Hit& hit)
  {
    x      = hit.x;
    y      = hit.y;
    z      = hit.z;
    t      = hit.t;
    dx2    = hit.dx2;
    dxy    = hit.dxy;
    dy2    = hit.dy2;
    dt2    = hit.dt2;
    rangeX = hit.rangeX;
    rangeY = hit.rangeY;
    rangeT = hit.rangeT;

    fIsSuppressed = 0;
  }

  fscal Z() const { return z; }
  fscal T() const { return t; }
  fscal X() const { return x; }
  fscal Y() const { return y; }
  fscal dX2() const { return dx2; }
  fscal dXY() const { return dxy; }
  fscal dY2() const { return dy2; }
  fscal dT2() const { return dt2; }
  fscal RangeX() const { return rangeX; }
  fscal RangeY() const { return rangeY; }
  fscal RangeT() const { return rangeT; }

  bool IsSuppressed() const { return fIsSuppressed; }

  void SetIsSuppresed(bool val) { fIsSuppressed = val; }

private:
  fscal x {0.}, y {0.}, z {0.}, t {0.}, dx2 {0.}, dxy {0.}, dy2 {0.}, dt2 {0.}, rangeX {0.}, rangeY {0.}, rangeT {0.};

  // fIsSuppressed flag is used to suppress duplicated hits at the module overlaps
  // TODO: collect those hits on the track instead of suppressing them
  bool fIsSuppressed {0};  // is the hit suppressed by another hit
};


#endif
