/* Copyright (C) 2007-2022 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergey Gorbunov [committer], Sergei Zharko */

#ifndef L1XYMeasurementInfo_h
#define L1XYMeasurementInfo_h 1

#include <string>

#include "CaConstants.h"
#include "L1Def.h"
#include "L1SimdSerializer.h"

using namespace cbm::algo::ca;

class L1XYMeasurementInfo {
public:
  /// Consistency checker
  void CheckConsistency() const;

  /// String representation of class contents
  /// \param indentLevel      number of indent characters in the output
  std::string ToString(int indentLevel = 0) const;

  /// Checks, if the fields are NaN
  bool IsNaN() const
  {
    return constants::undef::IsUndefined(C00) || constants::undef::IsUndefined(C10)
           || constants::undef::IsUndefined(C11);
  }

  /// Serialization function
  friend class boost::serialization::access;
  template<class Archive>
  void serialize(Archive& ar, const unsigned int)
  {
    ar& C00;
    ar& C10;
    ar& C11;
  }

public:
  fvec C00 {constants::undef::Fscal};
  fvec C10 {constants::undef::Fscal};
  fvec C11 {constants::undef::Fscal};

} _fvecalignment;


#endif
